#
# VHA6
#
# Copyright (c) 2019 Varnish Software AS
#
# Total Encryption export
# - Must be used manually when a shared secret key is used
#

import crypto;
import std;
import vha;

# Export on origin

sub vcl_deliver {
	if (req.method == "VHA_FETCH") {
		unset resp.http.vha6-crypto-pad;
		if (crypto.aes_get_length() > -1) {
			vha.log("VHA_FETCH ORIGIN: CRYPTO export");
			set resp.http.vha6-crypto-pad = crypto.aes_get_length();
		}
	}
}

# Import on peer

sub vcl_backend_response {
	if (bereq.method == "VHA_FETCH") {
		unset beresp.http.X-crypto-len;
		if (beresp.http.vha6-crypto-pad) {
			vha.log("VHA_BROADCAST PEER: CRYPTO import");
			set beresp.http.X-crypto-len = beresp.http.vha6-crypto-pad;
		}

		unset beresp.http.vha6-crypto-pad;
	}
}

# Unpad on normal client delivery
# TODO move this to support writing the padding on response?

sub vcl_deliver {
	if (req.method !~ "^VHA") {
		if (resp.http.X-crypto-len) {
			crypto.aes_set_length(std.integer(resp.http.X-crypto-len, 0));
		}
	}
}

# EOF
