#
# VHA6
#
# Copyright (c) 2019 Varnish Software AS
#
# Initialization
#

sub vcl_init {
	# Settings
	new vha6_opts = kvstore.init();
	vha6_opts.set("version", "6.9");

	# Token must be set by parent VCL
	#vha6_opts.set("token", "secret");

	# These are optional (default values or fallback options shown)
	#vha6_opts.set("allow_localhost", "false");
	#vha6_opts.set("allow_stale", "false");
	#vha6_opts.set("broadcast_limit", <broadcast_rate_limit>);
	#vha6_opts.set("broadcast_rate_limit", <max_requests_sec>);
	#vha6_opts.set("broadcaster_scheme", "http");
	#vha6_opts.set("broadcaster_host", "localhost");
	#vha6_opts.set("broadcaster_port", "8088");
	#vha6_opts.set("broadcaster_ssl_verify_peer", "true");
	#vha6_opts.set("broadcaster_ssl_verify_host", "true");
	#vha6_opts.set("broadcaster_group", "");
	#vha6_opts.set("broadcaster_force_sync", "false");
	#vha6_opts.set("fetch_timeout", "");
	#vha6_opts.set("force_update", "false");
	#vha6_opts.set("force_fast304", "false");
	#vha6_opts.set("keep_alive", "120s");
	#vha6_opts.set("origin_scheme", "");
	#vha6_opts.set("origin", "");
	#vha6_opts.set("origin_port", "");
	#vha6_opts.set("origin_ssl", "")
	#vha6_opts.set("origin_ssl_sni", "true")
	#vha6_opts.set("origin_ssl_verify_peer", "true")
	#vha6_opts.set("origin_ssl_verify_host", "false")
	#vha6_opts.set("peer_stream", "true");
	#vha6_opts.set("min_ttl", "3s");
	#vha6_opts.set("max_bytes", "25000000");
	#vha6_opts.set("request_rate_limit", <broadcast_rate_limit * 2.5>);
	#vha6_opts.set("token_ttl", "2m");
	#vha6_opts.set("vcs", "true");
	#vha6_opts.set("vcs_key", "vcs-key");
	#vha6_opts.set("origin_backend_linger", "10s");

	# This option is deprecated, and is replaced by new limits for the
	# different use cases it conflates:
	#
	# - broadcast_limit (indirectly)
	# - broadcast_rate_limit
	# - request_rate_limit (indirectly)
	#
	# Existing code relying on max_requests_sec should not break, but
	# behave slightly differently with an incoming request rate limit
	# consistent with the outgoing broadcast rate limit.
	#
	# It will eventually be removed.
	#
	#vha6_opts.set("max_requests_sec", "200");

	# Request settings
	new vha6_request = kvstore.init(scope = REQUEST);

	# These are optional (defaults shown)
	#vha6_request.set("skip", "false");
	#vha6_request.set("force_update", "false");

	# Stats
	new vha6_stats = kvstore.init();
	vha6_stats.set("start", now);
	vha6_stats.counter("broadcast_candidates", 0, varnishstat = true,
		comment = "Broadcast candidates");
	vha6_stats.counter("broadcasts", 0, varnishstat = true,
		comment = "Successful broadcasts");
	vha6_stats.counter("fetch_peer", 0, varnishstat = true,
		comment = "Broadcasts which hit this peer node (fetches)");
	vha6_stats.counter("fetch_origin", 0, varnishstat = true,
		comment = "Fetches which hit this origin node");
	vha6_stats.counter("fetch_origin_deliver", 0, varnishstat = true,
		comment = "Fetches which were delivered from origin to the peer");
	vha6_stats.counter("fetch_peer_insert", 0, varnishstat = true,
		comment = "Fetches which were successfully inserted");
	vha6_stats.counter("error_fetch", 0, varnishstat = true,
		comment = "Fetches which encountered a network error");
	vha6_stats.counter("error_fetch_insert", 0, varnishstat = true,
		comment = "Fetches which encoutnered an origin error");

	# nodes.conf
	new vha6_nodes = kvstore.init();
	vha6_nodes.init_conf("/etc/varnish/nodes.conf");

	# Hook
	call vha6_hook_init;

	vha.log("INIT: " + vha6_opts.get("version"));
}

sub vcl_recv {
	unset req.http.vha6-method;
	if (req.method !~ "^VHA") {
		unset req.http.vha6-url;
		unset req.http.vha6-version;
		unset req.http.vha6-token;
		unset req.http.vha6-vary;
		unset req.http.vha6-date;
		unset req.http.vha6-origin;
		unset req.http.vha6-origin-id;
		unset req.http.vha6-peer-id;
		unset req.http.vha6-force;
		unset req.http.vha6-xid;
	}
}

sub vcl_backend_response {
	if (bereq.method !~ "^VHA") {
		unset bereq.http.vha6-seal;
	}
}

# EOF
