#
# VHA6
#
# Copyright (c) 2019 Varnish Software AS
#
# Automatic configuration
#

#
# VHA6 Architecture
#
#       Parent VCL
#           │
#           ▼
#       object insertion
#           │
#           └──◆─────▶ broadcast.vcl      origin.vcl
#              │            │              ▲      │
#              │         [hash]            │    (exports)
#       firewall.vcl        │              │      │
#                     VHA_BROADCAST        │     object
# ORIGIN                    │              │      │
#                     *broadcaster*        │      │
#                         │││              │      │
# ══ security.vcl ════════│││══════════════│══════│═══════
#                         │││              │      │
# PEER(S)                 ▼▼│             VHA_FETCH
#                           │              │      │
#                           │           [hash]    │
#                           │  ┌───────────┘      │
#                           ▼  │                  │
#                         peer.vcl ◀──────────────┘
#

#
# Usage:
#
#	include "vha6/vha_auto.vcl";
#
#	sub vcl_init {
#		vha6_opts.set("token", "secret");
#		call vha6_token_init;
#	}
#

vcl 4.1;

import blob;
import crypto;
import goto;
import http;
import kvstore;
import std;
import vha;

include "vha6/states/init.vcl";
include "vha6/states/security.vcl";
include "vha6/exports/stevedore.vcl";
include "vha6/exports/slicer.vcl";
include "vha6/exports/brotli.vcl";
include "vha6/exports/crypto.vcl";
include "vha6/exports/esi_41.vcl";
include "vha6/exports/edgestash.vcl";
include "vha6/exports/hash_always_miss.vcl";
include "vha6/exports/xbody.vcl";
include "vha6/exports/ykey.vcl";
include "vha6/exports/fast_304.vcl";
include "vha6/hooks/states.vcl";
include "vha6/states/broadcast.vcl";
include "vha6/states/peer.vcl";
include "vha6/states/origin.vcl";
include "vha6/states/vha_agent.vcl";
include "vha6/states/firewall.vcl";

# EOF
